@@ -862,12 +862,13 @@ dequeue_pending_idle_callback (gpointer callback_data)
 				nautilus_file_ref (file);
 				changed_files = g_list_prepend (changed_files, file);
 			}
+			nautilus_file_ref (file);			
 		} else {
 			/* new file, create a nautilus file object and add it to the list */
 			file = nautilus_file_new_from_info (directory, file_info);
 			nautilus_directory_add_file (directory, file);			
-			added_files = g_list_prepend (added_files, file);
 		}
+		added_files = g_list_prepend (added_files, file);
 	}
 
 	/* If we are done loading, then we assume that any unconfirmed
@@ -1931,7 +1932,7 @@ read_dot_hidden_file (NautilusDirectory *directory)
 	if (gnome_vfs_get_file_info_uri (
 		dot_hidden_vfs_uri,
 		file_info, 
-		GNOME_VFS_FILE_INFO_DEFAULT) != GNOME_VFS_OK) {
+		GNOME_VFS_FILE_INFO_FOLLOW_LINKS) != GNOME_VFS_OK) {
 		gnome_vfs_uri_unref (dot_hidden_vfs_uri);
 		gnome_vfs_file_info_unref (file_info);
 		return;
