@@ -45,6 +45,7 @@ struct NautilusDirectoryDetails
 	/* The location. */
 	char *uri;
 	GnomeVFSURI *vfs_uri;
+	int is_local_state;
 
 	/* The file objects. */
 	NautilusFile *as_file;
@@ -103,6 +104,8 @@ struct NautilusDirectoryDetails
 	GnomeVFSAsyncHandle *get_info_in_progress;
 	gboolean get_info_has_slow_mime_type;
 
+	int is_in_trash_state;
+
 	NautilusFile *slow_mime_type_file;
 	GnomeVFSAsyncHandle *slow_mime_type_in_progress;
 
@@ -130,6 +133,7 @@ typedef struct {
 	gboolean metafile;
 	gboolean mime_list;
 	gboolean top_left_text;
+	gboolean large_top_left_text;
 	gboolean extension_info;
 	gboolean slow_mime_type;
 } Request;
