@@ -40,7 +40,6 @@
 #include "nautilus-main.h"
 #include "nautilus-query-editor.h"
 #include "nautilus-search-bar.h"
-#include "nautilus-signaller.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-zoom-control.h"
 #include <eel/eel-debug.h>
@@ -59,7 +58,7 @@
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkuimanager.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnome/gnome-macros.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-messagebox.h>
@@ -81,6 +80,7 @@
 #include <libnautilus-private/nautilus-undo.h>
 #include <libnautilus-private/nautilus-search-directory.h>
 #include <libnautilus-private/nautilus-search-engine.h>
+#include <libnautilus-private/nautilus-signaller.h>
 #include <math.h>
 #include <sys/time.h>
 
@@ -110,7 +110,6 @@ struct _NautilusSpatialWindowDetails {
 static const GtkTargetEntry location_button_drag_types[] = {
 	{ NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE, 0, NAUTILUS_ICON_DND_GNOME_ICON_LIST },
 	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
-	{ NAUTILUS_ICON_DND_URL_TYPE, 0, NAUTILUS_ICON_DND_URL },
 };
 
 GNOME_CLASS_BOILERPLATE (NautilusSpatialWindow, nautilus_spatial_window,
@@ -192,6 +191,25 @@ nautilus_spatial_window_unrealize (GtkWidget *widget)
 	}
 }
 
+static gboolean
+nautilus_spatial_window_state_event (GtkWidget *widget,
+				     GdkEventWindowState *event)
+{
+	if (event->changed_mask & GDK_WINDOW_STATE_MAXIMIZED &&
+	    NAUTILUS_WINDOW (widget)->details->viewed_file != NULL) {
+		nautilus_file_set_boolean_metadata (NAUTILUS_WINDOW (widget)->details->viewed_file,
+						    NAUTILUS_METADATA_KEY_WINDOW_MAXIMIZED,
+						    FALSE,
+						    event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED);
+	}
+
+	if (GTK_WIDGET_CLASS (parent_class)->window_state_event != NULL) {
+		return GTK_WIDGET_CLASS (parent_class)->window_state_event (widget, event);
+	}
+
+	return FALSE;
+}
+
 static void
 nautilus_spatial_window_destroy (GtkObject *object)
 {
@@ -394,22 +412,25 @@ real_get_icon_name (NautilusWindow *window)
 	return nautilus_icon_factory_get_icon_for_file (window->details->viewed_file, FALSE);
 }
 
-static void
+static gboolean
 real_set_title (NautilusWindow *window, const char *title)
 {
+	gboolean changed;
 
-	EEL_CALL_PARENT (NAUTILUS_WINDOW_CLASS,
-			 set_title, (window, title));
-	
-	if (title[0] == '\0') {
+	changed = EEL_CALL_PARENT_WITH_RETURN_VALUE
+		(NAUTILUS_WINDOW_CLASS, set_title, (window, title));
+
+	if (changed && title[0] == '\0') {
 		gtk_window_set_title (GTK_WINDOW (window), _("Nautilus"));
-	} else {
+	} else if (changed) {
 		char *window_title;
 
 		window_title = eel_str_middle_truncate (title, MAX_TITLE_LENGTH);
 		gtk_window_set_title (GTK_WINDOW (window), window_title);
 		g_free (window_title);
 	}
+
+	return changed;
 }
 
 static void
@@ -805,7 +826,13 @@ static void
 action_add_bookmark_callback (GtkAction *action,
 			      gpointer user_data)
 {
-        nautilus_window_add_bookmark_for_current_location (NAUTILUS_WINDOW (user_data));
+	NautilusWindow *window;
+
+	window = NAUTILUS_WINDOW (user_data);
+
+	if (!NAUTILUS_IS_DESKTOP_WINDOW (window)) { /* don't bookmark x-nautilus-desktop:/// */
+		nautilus_window_add_bookmark_for_current_location (window);
+	}
 }
 
 static void
@@ -975,6 +1002,7 @@ nautilus_spatial_window_class_init (NautilusSpatialWindowClass *class)
 	GTK_WIDGET_CLASS (class)->show = nautilus_spatial_window_show;
 	GTK_WIDGET_CLASS (class)->configure_event = nautilus_spatial_window_configure_event;
 	GTK_WIDGET_CLASS (class)->unrealize = nautilus_spatial_window_unrealize;
+	GTK_WIDGET_CLASS (class)->window_state_event = nautilus_spatial_window_state_event;
 
 	NAUTILUS_WINDOW_CLASS (class)->prompt_for_location = 
 		real_prompt_for_location;
